/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.object.model;

import com.liferay.portal.kernel.bean.AutoEscape;
import com.liferay.portal.kernel.model.BaseModel;
import com.liferay.portal.kernel.model.MVCCModel;
import com.liferay.portal.kernel.model.ShardedModel;
import com.liferay.portal.kernel.model.StagedAuditedModel;

import java.util.Date;

import org.osgi.annotation.versioning.ProviderType;

/**
 * The base model interface for the ObjectActionEntry service. Represents a row in the &quot;ObjectActionEntry&quot; database table, with each column mapped to a property of this class.
 *
 * <p>
 * This interface and its corresponding implementation <code>com.liferay.object.model.impl.ObjectActionEntryModelImpl</code> exist only as a container for the default property accessors generated by ServiceBuilder. Helper methods and all application logic should be put in <code>com.liferay.object.model.impl.ObjectActionEntryImpl</code>.
 * </p>
 *
 * @author Marco Leo
 * @see ObjectActionEntry
 * @generated
 */
@ProviderType
public interface ObjectActionEntryModel
	extends BaseModel<ObjectActionEntry>, MVCCModel, ShardedModel,
			StagedAuditedModel {

	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. All methods that expect a object action entry model instance should use the {@link ObjectActionEntry} interface instead.
	 */

	/**
	 * Returns the primary key of this object action entry.
	 *
	 * @return the primary key of this object action entry
	 */
	public long getPrimaryKey();

	/**
	 * Sets the primary key of this object action entry.
	 *
	 * @param primaryKey the primary key of this object action entry
	 */
	public void setPrimaryKey(long primaryKey);

	/**
	 * Returns the mvcc version of this object action entry.
	 *
	 * @return the mvcc version of this object action entry
	 */
	@Override
	public long getMvccVersion();

	/**
	 * Sets the mvcc version of this object action entry.
	 *
	 * @param mvccVersion the mvcc version of this object action entry
	 */
	@Override
	public void setMvccVersion(long mvccVersion);

	/**
	 * Returns the uuid of this object action entry.
	 *
	 * @return the uuid of this object action entry
	 */
	@AutoEscape
	@Override
	public String getUuid();

	/**
	 * Sets the uuid of this object action entry.
	 *
	 * @param uuid the uuid of this object action entry
	 */
	@Override
	public void setUuid(String uuid);

	/**
	 * Returns the object action entry ID of this object action entry.
	 *
	 * @return the object action entry ID of this object action entry
	 */
	public long getObjectActionEntryId();

	/**
	 * Sets the object action entry ID of this object action entry.
	 *
	 * @param objectActionEntryId the object action entry ID of this object action entry
	 */
	public void setObjectActionEntryId(long objectActionEntryId);

	/**
	 * Returns the company ID of this object action entry.
	 *
	 * @return the company ID of this object action entry
	 */
	@Override
	public long getCompanyId();

	/**
	 * Sets the company ID of this object action entry.
	 *
	 * @param companyId the company ID of this object action entry
	 */
	@Override
	public void setCompanyId(long companyId);

	/**
	 * Returns the user ID of this object action entry.
	 *
	 * @return the user ID of this object action entry
	 */
	@Override
	public long getUserId();

	/**
	 * Sets the user ID of this object action entry.
	 *
	 * @param userId the user ID of this object action entry
	 */
	@Override
	public void setUserId(long userId);

	/**
	 * Returns the user uuid of this object action entry.
	 *
	 * @return the user uuid of this object action entry
	 */
	@Override
	public String getUserUuid();

	/**
	 * Sets the user uuid of this object action entry.
	 *
	 * @param userUuid the user uuid of this object action entry
	 */
	@Override
	public void setUserUuid(String userUuid);

	/**
	 * Returns the user name of this object action entry.
	 *
	 * @return the user name of this object action entry
	 */
	@AutoEscape
	@Override
	public String getUserName();

	/**
	 * Sets the user name of this object action entry.
	 *
	 * @param userName the user name of this object action entry
	 */
	@Override
	public void setUserName(String userName);

	/**
	 * Returns the create date of this object action entry.
	 *
	 * @return the create date of this object action entry
	 */
	@Override
	public Date getCreateDate();

	/**
	 * Sets the create date of this object action entry.
	 *
	 * @param createDate the create date of this object action entry
	 */
	@Override
	public void setCreateDate(Date createDate);

	/**
	 * Returns the modified date of this object action entry.
	 *
	 * @return the modified date of this object action entry
	 */
	@Override
	public Date getModifiedDate();

	/**
	 * Sets the modified date of this object action entry.
	 *
	 * @param modifiedDate the modified date of this object action entry
	 */
	@Override
	public void setModifiedDate(Date modifiedDate);

	/**
	 * Returns the object definition ID of this object action entry.
	 *
	 * @return the object definition ID of this object action entry
	 */
	public long getObjectDefinitionId();

	/**
	 * Sets the object definition ID of this object action entry.
	 *
	 * @param objectDefinitionId the object definition ID of this object action entry
	 */
	public void setObjectDefinitionId(long objectDefinitionId);

	/**
	 * Returns the active of this object action entry.
	 *
	 * @return the active of this object action entry
	 */
	public boolean getActive();

	/**
	 * Returns <code>true</code> if this object action entry is active.
	 *
	 * @return <code>true</code> if this object action entry is active; <code>false</code> otherwise
	 */
	public boolean isActive();

	/**
	 * Sets whether this object action entry is active.
	 *
	 * @param active the active of this object action entry
	 */
	public void setActive(boolean active);

	/**
	 * Returns the object action trigger key of this object action entry.
	 *
	 * @return the object action trigger key of this object action entry
	 */
	@AutoEscape
	public String getObjectActionTriggerKey();

	/**
	 * Sets the object action trigger key of this object action entry.
	 *
	 * @param objectActionTriggerKey the object action trigger key of this object action entry
	 */
	public void setObjectActionTriggerKey(String objectActionTriggerKey);

	/**
	 * Returns the parameters of this object action entry.
	 *
	 * @return the parameters of this object action entry
	 */
	@AutoEscape
	public String getParameters();

	/**
	 * Sets the parameters of this object action entry.
	 *
	 * @param parameters the parameters of this object action entry
	 */
	public void setParameters(String parameters);

	/**
	 * Returns the type of this object action entry.
	 *
	 * @return the type of this object action entry
	 */
	@AutoEscape
	public String getType();

	/**
	 * Sets the type of this object action entry.
	 *
	 * @param type the type of this object action entry
	 */
	public void setType(String type);

	@Override
	public ObjectActionEntry cloneWithOriginalValues();

}